nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Abort1

Struct Abort1 

#[repr(transparent)]
pub struct Abort1(pub u32);
Channel Abort control for all DMA channels.

Tuple Fields

0: u32

Implementations

Source

impl Abort1

pub const fn abort32(&self) -> bool

Abort control for DMA channel 32.

pub const fn set_abort32(&mut self, val: bool)

Abort control for DMA channel 32.

pub const fn abort63_33(&self) -> Abort6333

Additional Abort controls for remaining DMA channels in the range 63 to 33. Any bits above the actually implemented channels are reserved.

pub const fn set_abort63_33(&mut self, val: Abort6333)

Additional Abort controls for remaining DMA channels in the range 63 to 33. Any bits above the actually implemented channels are reserved.