nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Active1

Struct Active1 

#[repr(transparent)]
pub struct Active1(pub u32);
Channel Active status for all DMA channels.

Tuple Fields

0: u32

Implementations

Source

impl Active1

pub const fn active32(&self) -> bool

Active flag for DMA channel 32.

pub const fn set_active32(&mut self, val: bool)

Active flag for DMA channel 32.

pub const fn active63_33(&self) -> Active6333

Additional Active flags for remaining DMA channels in the range 63 to 33. Any bits above the actually implemented channels are reserved.

pub const fn set_active63_33(&mut self, val: Active6333)

Additional Active flags for remaining DMA channels in the range 63 to 33. Any bits above the actually implemented channels are reserved.