nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Busy1

Struct Busy1 

#[repr(transparent)]
pub struct Busy1(pub u32);
Channel Busy status for all DMA channels.

Tuple Fields

0: u32

Implementations

Source

impl Busy1

pub const fn busy32(&self) -> bool

Busy flag for DMA channel 32.

pub const fn set_busy32(&mut self, val: bool)

Busy flag for DMA channel 32.

pub const fn busy63_33(&self) -> Busy6333

Additional Active flags for remaining DMA channels in the range 63 to 33. Any bits above the actually implemented channels are reserved.

pub const fn set_busy63_33(&mut self, val: Busy6333)

Additional Active flags for remaining DMA channels in the range 63 to 33. Any bits above the actually implemented channels are reserved.