#[repr(transparent)]pub struct Ctlstat(pub u32);Expand description
Control and status register for DMA channel .
Tuple Fields
0: u32Implementations
Sourceimpl Ctlstat
impl Ctlstat
Sourcepub const fn validpending(&self) -> Validpending
pub const fn validpending(&self) -> Validpending
Valid pending flag for this channel. This bit is set when a 1 is written to the corresponding bit in the related SETVALID register when CFGVALID = 1 for the same channel.
Sourcepub const fn set_validpending(&mut self, val: Validpending)
pub const fn set_validpending(&mut self, val: Validpending)
Valid pending flag for this channel. This bit is set when a 1 is written to the corresponding bit in the related SETVALID register when CFGVALID = 1 for the same channel.