nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Errint1

Struct Errint1 

#[repr(transparent)]
pub struct Errint1(pub u32);
Error Interrupt status for all DMA channels.

Tuple Fields

0: u32

Implementations

Source

impl Errint1

pub const fn err32(&self) -> Err32

Error Interrupt flag for DMA channel 32.

pub const fn set_err32(&mut self, val: Err32)

Error Interrupt flag for DMA channel 32.

pub const fn err63_33(&self) -> Err6333

Additional error Interrupt flags for remaining DMA channels in the range 63 to 33. Any bits above the actually implemented channels are reserved.

pub const fn set_err63_33(&mut self, val: Err6333)

Additional error Interrupt flags for remaining DMA channels in the range 63 to 33. Any bits above the actually implemented channels are reserved.