nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Inta1

Struct Inta1 

#[repr(transparent)]
pub struct Inta1(pub u32);
Interrupt A status for all DMA channels.

Tuple Fields

0: u32

Implementations

Source

impl Inta1

pub const fn inta32(&self) -> bool

Interrupt A status for DMA channel 32.

pub const fn set_inta32(&mut self, val: bool)

Interrupt A status for DMA channel 32.

pub const fn inta63_33(&self) -> Inta6333

Additional Interrupt A status bits for remaining DMA channels in the range 63 to 33. Any bits above the actually implemented channels are reserved.

pub const fn set_inta63_33(&mut self, val: Inta6333)

Additional Interrupt A status bits for remaining DMA channels in the range 63 to 33. Any bits above the actually implemented channels are reserved.