nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Intb1

Struct Intb1 

#[repr(transparent)]
pub struct Intb1(pub u32);
Interrupt B status for all DMA channels.

Tuple Fields

0: u32

Implementations

Source

impl Intb1

pub const fn intb32(&self) -> bool

Interrupt B status for DMA channel 32.

pub const fn set_intb32(&mut self, val: bool)

Interrupt B status for DMA channel 32.

pub const fn intb63_33(&self) -> Intb6333

Additional Interrupt B status bits for remaining DMA channels in the range 63 to 33. Any bits above the actually implemented channels are reserved.

pub const fn set_intb63_33(&mut self, val: Intb6333)

Additional Interrupt B status bits for remaining DMA channels in the range 63 to 33. Any bits above the actually implemented channels are reserved.