nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Intenclr1

Struct Intenclr1 

#[repr(transparent)]
pub struct Intenclr1(pub u32);
Interrupt Enable Clear for all DMA channels.

Tuple Fields

0: u32

Implementations

Source

impl Intenclr1

pub const fn clr(&self) -> u32

Writing ones to this register clears corresponding bits in the DMAIntEnSet1.

pub const fn set_clr(&mut self, val: u32)

Writing ones to this register clears corresponding bits in the DMAIntEnSet1.