nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Intenset1

Struct Intenset1 

#[repr(transparent)]
pub struct Intenset1(pub u32);
Interrupt Enable read and Set for all DMA channels.

Tuple Fields

0: u32

Implementations

Source

impl Intenset1

pub const fn inten32(&self) -> bool

Interrupt Enable read and set for DMA channel 32.

pub const fn set_inten32(&mut self, val: bool)

Interrupt Enable read and set for DMA channel 32.

pub const fn inten63_33(&self) -> Inten6333

Additional Interrupt Enable read and set bits for remaining DMA channels in the range 63 to 33. Any bits above the actually implemented channels are reserved.

pub const fn set_inten63_33(&mut self, val: Inten6333)

Additional Interrupt Enable read and set bits for remaining DMA channels in the range 63 to 33. Any bits above the actually implemented channels are reserved.