nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Settrig1

Struct Settrig1 

#[repr(transparent)]
pub struct Settrig1(pub u32);
Set Trigger control bits for all DMA channels.

Tuple Fields

0: u32

Implementations

Source

impl Settrig1

pub const fn settrig32(&self) -> bool

Set Trigger control bit for DMA channel 32.

pub const fn set_settrig32(&mut self, val: bool)

Set Trigger control bit for DMA channel 32.

pub const fn settrig63_33(&self) -> Settrig6333

Additional Set Trigger control bits for remaining DMA channels in the range 63 to 33. Any bits above the actually implemented channels are reserved.

pub const fn set_settrig63_33(&mut self, val: Settrig6333)

Additional Set Trigger control bits for remaining DMA channels in the range 63 to 33. Any bits above the actually implemented channels are reserved.