#[repr(transparent)]pub struct Abort1(pub u32);Expand description
Channel Abort control for all DMA channels.
Tuple Fields
0: u32Implementations
Sourceimpl Abort1
impl Abort1
Sourcepub const fn set_abort32(&mut self, val: bool)
pub const fn set_abort32(&mut self, val: bool)
Abort control for DMA channel 32.
Sourcepub const fn abort63_33(&self) -> Abort6333
pub const fn abort63_33(&self) -> Abort6333
Additional Abort controls for remaining DMA channels in the range 63 to 33. Any bits above the actually implemented channels are reserved.
Sourcepub const fn set_abort63_33(&mut self, val: Abort6333)
pub const fn set_abort63_33(&mut self, val: Abort6333)
Additional Abort controls for remaining DMA channels in the range 63 to 33. Any bits above the actually implemented channels are reserved.