#[repr(transparent)]pub struct Active1(pub u32);Expand description
Channel Active status for all DMA channels.
Tuple Fields
0: u32Implementations
Sourceimpl Active1
impl Active1
Sourcepub const fn set_active32(&mut self, val: bool)
pub const fn set_active32(&mut self, val: bool)
Active flag for DMA channel 32.
Sourcepub const fn active63_33(&self) -> Active6333
pub const fn active63_33(&self) -> Active6333
Additional Active flags for remaining DMA channels in the range 63 to 33. Any bits above the actually implemented channels are reserved.
Sourcepub const fn set_active63_33(&mut self, val: Active6333)
pub const fn set_active63_33(&mut self, val: Active6333)
Additional Active flags for remaining DMA channels in the range 63 to 33. Any bits above the actually implemented channels are reserved.