#[repr(transparent)]pub struct Busy1(pub u32);Expand description
Channel Busy status for all DMA channels.
Tuple Fields
0: u32Implementations
Sourceimpl Busy1
impl Busy1
Sourcepub const fn set_busy32(&mut self, val: bool)
pub const fn set_busy32(&mut self, val: bool)
Busy flag for DMA channel 32.
Sourcepub const fn busy63_33(&self) -> Busy6333
pub const fn busy63_33(&self) -> Busy6333
Additional Active flags for remaining DMA channels in the range 63 to 33. Any bits above the actually implemented channels are reserved.
Sourcepub const fn set_busy63_33(&mut self, val: Busy6333)
pub const fn set_busy63_33(&mut self, val: Busy6333)
Additional Active flags for remaining DMA channels in the range 63 to 33. Any bits above the actually implemented channels are reserved.