#[repr(transparent)]pub struct Errint1(pub u32);Expand description
Error Interrupt status for all DMA channels.
Tuple Fields
0: u32Implementations
Sourceimpl Errint1
impl Errint1
Sourcepub const fn err63_33(&self) -> Err6333
pub const fn err63_33(&self) -> Err6333
Additional error Interrupt flags for remaining DMA channels in the range 63 to 33. Any bits above the actually implemented channels are reserved.
Sourcepub const fn set_err63_33(&mut self, val: Err6333)
pub const fn set_err63_33(&mut self, val: Err6333)
Additional error Interrupt flags for remaining DMA channels in the range 63 to 33. Any bits above the actually implemented channels are reserved.