#[repr(transparent)]pub struct Inta1(pub u32);Expand description
Interrupt A status for all DMA channels.
Tuple Fields
0: u32Implementations
Sourceimpl Inta1
impl Inta1
Sourcepub const fn set_inta32(&mut self, val: bool)
pub const fn set_inta32(&mut self, val: bool)
Interrupt A status for DMA channel 32.
Sourcepub const fn inta63_33(&self) -> Inta6333
pub const fn inta63_33(&self) -> Inta6333
Additional Interrupt A status bits for remaining DMA channels in the range 63 to 33. Any bits above the actually implemented channels are reserved.
Sourcepub const fn set_inta63_33(&mut self, val: Inta6333)
pub const fn set_inta63_33(&mut self, val: Inta6333)
Additional Interrupt A status bits for remaining DMA channels in the range 63 to 33. Any bits above the actually implemented channels are reserved.