#[repr(transparent)]pub struct Intb1(pub u32);Expand description
Interrupt B status for all DMA channels.
Tuple Fields
0: u32Implementations
Sourceimpl Intb1
impl Intb1
Sourcepub const fn set_intb32(&mut self, val: bool)
pub const fn set_intb32(&mut self, val: bool)
Interrupt B status for DMA channel 32.
Sourcepub const fn intb63_33(&self) -> Intb6333
pub const fn intb63_33(&self) -> Intb6333
Additional Interrupt B status bits for remaining DMA channels in the range 63 to 33. Any bits above the actually implemented channels are reserved.
Sourcepub const fn set_intb63_33(&mut self, val: Intb6333)
pub const fn set_intb63_33(&mut self, val: Intb6333)
Additional Interrupt B status bits for remaining DMA channels in the range 63 to 33. Any bits above the actually implemented channels are reserved.