#[repr(transparent)]pub struct Intenset1(pub u32);Expand description
Interrupt Enable read and Set for all DMA channels.
Tuple Fields
0: u32Implementations
Sourceimpl Intenset1
impl Intenset1
Sourcepub const fn set_inten32(&mut self, val: bool)
pub const fn set_inten32(&mut self, val: bool)
Interrupt Enable read and set for DMA channel 32.
Sourcepub const fn inten63_33(&self) -> Inten6333
pub const fn inten63_33(&self) -> Inten6333
Additional Interrupt Enable read and set bits for remaining DMA channels in the range 63 to 33. Any bits above the actually implemented channels are reserved.
Sourcepub const fn set_inten63_33(&mut self, val: Inten6333)
pub const fn set_inten63_33(&mut self, val: Inten6333)
Additional Interrupt Enable read and set bits for remaining DMA channels in the range 63 to 33. Any bits above the actually implemented channels are reserved.