#[repr(transparent)]pub struct Settrig1(pub u32);Expand description
Set Trigger control bits for all DMA channels.
Tuple Fields
0: u32Implementations
Sourceimpl Settrig1
impl Settrig1
Sourcepub const fn set_settrig32(&mut self, val: bool)
pub const fn set_settrig32(&mut self, val: bool)
Set Trigger control bit for DMA channel 32.
Sourcepub const fn settrig63_33(&self) -> Settrig6333
pub const fn settrig63_33(&self) -> Settrig6333
Additional Set Trigger control bits for remaining DMA channels in the range 63 to 33. Any bits above the actually implemented channels are reserved.
Sourcepub const fn set_settrig63_33(&mut self, val: Settrig6333)
pub const fn set_settrig63_33(&mut self, val: Settrig6333)
Additional Set Trigger control bits for remaining DMA channels in the range 63 to 33. Any bits above the actually implemented channels are reserved.