#[repr(transparent)]pub struct Setvalid1(pub u32);Expand description
Set ValidPending control bits for all DMA channels.
Tuple Fields
0: u32Implementations
Sourceimpl Setvalid1
impl Setvalid1
Sourcepub const fn setvalid32(&self) -> bool
pub const fn setvalid32(&self) -> bool
SetValid control for DMA channel 32.
Sourcepub const fn set_setvalid32(&mut self, val: bool)
pub const fn set_setvalid32(&mut self, val: bool)
SetValid control for DMA channel 32.
Sourcepub const fn setvalid63_33(&self) -> Setvalid6333
pub const fn setvalid63_33(&self) -> Setvalid6333
Additional SetValid controls for remaining DMA channels in the range 63 to 33. Any bits above the actually implemented channels are reserved.
Sourcepub const fn set_setvalid63_33(&mut self, val: Setvalid6333)
pub const fn set_setvalid63_33(&mut self, val: Setvalid6333)
Additional SetValid controls for remaining DMA channels in the range 63 to 33. Any bits above the actually implemented channels are reserved.